@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "importwizard.h"
 #include "importwizardkernel.h"
@@ -38,6 +25,7 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
+#include <KConfigGroup>
 #include "importwizard_debug.h"
 #include <KMessageBox>
 #include <KHelpMenu>
@@ -55,7 +43,7 @@ ImportWizard::ImportWizard(WizardMode mode, QWidget *parent)
     setStandardButtons(QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     mAbstractDisplayInfo = new ImportWizardDisplayInfo(this);
 
-    ImportWizardKernel *kernel = new ImportWizardKernel(this);
+    auto *kernel = new ImportWizardKernel(this);
     CommonKernel->registerKernelIf(kernel);   //register KernelIf early, it is used by the Filter classes
     CommonKernel->registerSettingsIf(kernel);   //SettingsIf is used in FolderTreeWidget
     createAutomaticModePage();
@@ -344,9 +332,9 @@ void ImportWizard::next()
 
         finishButton()->setEnabled(false);
 
-        MailImporter::FilterInfo *info = new MailImporter::FilterInfo();
-        MailImporter::FilterImporterAkonadi *filterImporter = new MailImporter::FilterImporterAkonadi(info);
-        ImportWizardFilterInfoGui *infoGui = new ImportWizardFilterInfoGui(mImportpage, this);
+        auto *info = new MailImporter::FilterInfo();
+        auto *filterImporter = new MailImporter::FilterImporterAkonadi(info);
+        auto *infoGui = new ImportWizardFilterInfoGui(mImportpage, this);
         info->setFilterInfoGui(infoGui);
         info->setStatusMessage(i18n("Import in progress"));
         info->setRemoveDupMessage(mSelfilterpage->removeDupMsg_checked());
